==> deepin-font-manager_5.8.0.13.orig.tar.xz: deepin-font-manager-5.8.0.13/translations/deepin-font-manager_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>所有字体</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统字体</translation>
    </message>
    <message>
        <source>User</source>
        <translation>用户字体</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>已激活</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>中文字体</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>等宽字体</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>文件已损坏</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>已安装相同版本</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>系统字体</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>字体</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>已安装%1个字体</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>已安装%1个字体</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete this font?</source>
        <translation>您确定要删除该字体吗？</translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation>删除后该字体将不可用于其他应用程序</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>删除后这些字体将不可用于其他应用程序</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>无法删除其他%1个系统字体</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>无法删除正在使用的字体：%1</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>无法删除其他%1个系统字体和正在使用的字体：%2</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>您确定要删除这%1个字体吗？</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>正在删除字体，请稍候...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>字体验证</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>无可用安装字体</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>因理想而出生，为责任而成长</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>基本信息</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>样式</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>全名</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>PS名称</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>商标</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>字体管理器</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>字体管理器是一款帮助用户安装和管理字体的工具。</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>正在加载字体，请稍候...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>该字体已导出到桌面</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1个字体已导出到桌面</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>目标磁盘空间不足，1 个文件导出失败</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>目标磁盘空间不足，%1 个文件导出失败</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>添加字体</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>启用字体</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>禁用字体</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除字体</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出字体</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>字体已被禁用</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1正在被使用，无法禁用</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>不可禁用系统字体和使用中的字体</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>不可禁用系统字体</translation>
    </message>
    <message>
        <source>Some fonts are not allowed to be disabled</source>
        <translation>部分系统字体不允许被禁用</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>安装字体</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>正在验证...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>文件已损坏</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>已安装</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>未安装</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>安装字体</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>暂无字体</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>上一页</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>下一页</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>添加字体</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>字体信息</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>输入文本内容进行预览</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>文件已损坏</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_5.9.14.orig.tar.xz: deepin-font-manager-5.9.14/translations/deepin-font-manager_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>所有字体</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统字体</translation>
    </message>
    <message>
        <source>User</source>
        <translation>用户字体</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>已激活</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>中文字体</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>等宽字体</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1是一个字体集，将它删除可能会删除属于它的所有字体</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>删 除</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1是一个字体集，将它启用可能会启用属于它的所有字体</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1是一个字体集，将它禁用可能会禁用属于它的所有字体</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>启 用</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>禁 用</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>应用到所有选定的字体集</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>文件已损坏</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>已安装相同版本</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>系统字体</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>已安装%1个字体</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>已安装%1个字体</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>目标磁盘空间不足，%1 个文件安装失败</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>目标磁盘空间不足，%1 个文件安装失败</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>删除后该字体将不可用于其他应用程序</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>删除后这些字体将不可用于其他应用程序</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>无法删除其他%1个系统字体</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>无法删除正在使用的字体：%1</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>无法删除其他%1个系统字体和正在使用的字体：%2</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>您确定要删除这%1个字体吗？</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>删 除</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>正在删除字体，请稍候...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>字体验证</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>无可用安装字体</translation>
    </message>
    <message>
        <source>Exit</source>
        <comment>button</comment>
        <translation>退 出</translation>
    </message>
    <message>
        <source>Continue</source>
        <comment>button</comment>
        <translation>继 续</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>基本信息</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>样式</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>全名</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>PS名称</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>商标</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>字体管理器</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>字体管理器是一款帮助用户安装和管理字体的工具。</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>正在加载字体，请稍候...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>该字体已导出到桌面</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1个字体已导出到桌面</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>目标磁盘空间不足，1 个文件导出失败</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>目标磁盘空间不足，%1 个文件导出失败</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>添加字体</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>启用字体</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>禁用字体</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除字体</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出字体</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>已禁用</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>字体已被禁用</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1正在被使用，无法禁用</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>不可禁用系统字体和使用中的字体</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>不可禁用系统字体</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>安装字体</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>正在验证...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>文件已损坏</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>已安装</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>未安装</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>安装字体</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>暂无字体</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>上一页</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>下一页</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>添加字体</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>字体信息</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>输入文本内容进行预览</translation>
    </message>
</context>
</TS>
